==> igniteui-webcomponents-core-4.0.2.tgz: package/esm2015/lib/SlowStochasticOscillatorIndicatorDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { StrategyBasedIndicatorDescriptionMetadata } from "./StrategyBasedIndicatorDescriptionMetadata";
import { SlowStochasticOscillatorIndicatorDescription } from "./SlowStochasticOscillatorIndicatorDescription";
/**
 * @hidden
 */
export let SlowStochasticOscillatorIndicatorDescriptionMetadata = /*@__PURE__*/ (() => {
    class SlowStochasticOscillatorIndicatorDescriptionMetadata extends Base {
        static b(a) {
            if (SlowStochasticOscillatorIndicatorDescriptionMetadata.a == null) {
                SlowStochasticOscillatorIndicatorDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                SlowStochasticOscillatorIndicatorDescriptionMetadata.c(SlowStochasticOscillatorIndicatorDescriptionMetadata.a);
            }
            if (a.j(SlowStochasticOscillatorIndicatorDescriptionMetadata.a)) {
                return;
            }
            a.y(SlowStochasticOscillatorIndicatorDescriptionMetadata.a);
        }
        static c(a) {
            StrategyBasedIndicatorDescriptionMetadata.c(a);
            a.item("Period", "Number:int");
        }
        static d(a) {
            SlowStochasticOscillatorIndicatorDescriptionMetadata.b(a);
            a.aa("SlowStochasticOscillatorIndicator", () => new SlowStochasticOscillatorIndicatorDescription());
            a.z("SlowStochasticOscillatorIndicator", SlowStochasticOscillatorIndicatorDescriptionMetadata.a);
        }
    }
    SlowStochasticOscillatorIndicatorDescriptionMetadata.$t = /*@__PURE__*/ markType(SlowStochasticOscillatorIndicatorDescriptionMetadata, 'SlowStochasticOscillatorIndicatorDescriptionMetadata');
    SlowStochasticOscillatorIndicatorDescriptionMetadata.a = null;
    return SlowStochasticOscillatorIndicatorDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/SlowStochasticOscillatorIndicatorDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { StrategyBasedIndicatorDescriptionMetadata } from "./StrategyBasedIndicatorDescriptionMetadata";
import { SlowStochasticOscillatorIndicatorDescription } from "./SlowStochasticOscillatorIndicatorDescription";
/**
 * @hidden
 */
export let SlowStochasticOscillatorIndicatorDescriptionMetadata = /*@__PURE__*/ (() => {
    class SlowStochasticOscillatorIndicatorDescriptionMetadata extends Base {
        static b(a) {
            if (SlowStochasticOscillatorIndicatorDescriptionMetadata.a == null) {
                SlowStochasticOscillatorIndicatorDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                SlowStochasticOscillatorIndicatorDescriptionMetadata.c(SlowStochasticOscillatorIndicatorDescriptionMetadata.a);
            }
            if (a.k(SlowStochasticOscillatorIndicatorDescriptionMetadata.a)) {
                return;
            }
            a.aa(SlowStochasticOscillatorIndicatorDescriptionMetadata.a);
        }
        static c(a) {
            StrategyBasedIndicatorDescriptionMetadata.c(a);
            a.item("Period", "Number:int");
        }
        static d(a) {
            SlowStochasticOscillatorIndicatorDescriptionMetadata.b(a);
            a.ac("SlowStochasticOscillatorIndicator", () => new SlowStochasticOscillatorIndicatorDescription());
            a.ab("SlowStochasticOscillatorIndicator", SlowStochasticOscillatorIndicatorDescriptionMetadata.a);
        }
    }
    SlowStochasticOscillatorIndicatorDescriptionMetadata.$t = /*@__PURE__*/ markType(SlowStochasticOscillatorIndicatorDescriptionMetadata, 'SlowStochasticOscillatorIndicatorDescriptionMetadata');
    SlowStochasticOscillatorIndicatorDescriptionMetadata.a = null;
    return SlowStochasticOscillatorIndicatorDescriptionMetadata;
})();
